(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9750,        253]*)
(*NotebookOutlinePosition[     11520,        308]*)
(*  CellTagsIndexPosition[     11476,        304]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Einleitung"]], "Title",
  CounterAssignments->{{"Title", 3}}],

Cell["Der Titel der vorliegenden Arbeit lautet:", "Text"],

Cell[TextData[StyleBox[
"Fraktionale Diffusionsgleichungen und Foxsche H-Funktionen\nmit Beispielen \
aus der Physik."]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox[
  "Die fraktionalen Diffusionsgleichungen beschreiben in besonders einfacher \
Weise die Ph\[ADoubleDot]nomene der anomalen Diffusion. Sie stellen bei \
eindimensionaler Formulierung einen kontinuierlichen \
\[CapitalUDoubleDot]bergang (Schneider und Wyss "],
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") zwischen der Fickschen Diffusionsgleichung und der Wellengleichung dar, \
indem die Ordnung der zeitlichen Differentiation kontinuierlich ge\
\[ADoubleDot]ndert wird. F\[UDoubleDot]r die Auswertung physikalischer \
Me\[SZ]daten zur Diffusion wird im Rahmen dieser Arbeit die Bedeutung der \
Varianzanalyse hervorgehoben. Die bereits von A. Einstein angegebene Relation \
zur normalen Diffusion ist im Rahmen dieser Arbeit zu pr\[ADoubleDot]zisieren \
und konsistent f\[UDoubleDot]r die anomale Diffusion zu verallgemeinern. \
Hierzu gibt es Vorarbeiten (West et al. "],
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  "). Die G\[UDoubleDot]ltigkeit der Einstein-Relation auch f\[UDoubleDot]r \
diffusive Prozesse mit endlicher Ausbreitungsgeschwindigkeit wird am Rande \
mitbehandelt (Kapitel 1)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Die Foxschen H-Funktionen und ihre Fourier-Faltungen stellen den L\
\[ODoubleDot]sungsraum (Schneider und Wyss "],
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") der hier behandelten fraktionalen Diffusionsgleichungen dar. Die \
Foxschen H-Funktionen (Dixon und Ferrar "],
  ButtonBox["[DF1936]",
    ButtonData:>{"Literatur.nb", "[DF1936]"},
    ButtonStyle->"Hyperlink"],
  StyleBox["; Fox  "],
  ButtonBox["[Fox1961]",
    ButtonData:>{"Literatur.nb", "[Fox1961]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[") werden als Mellin-Barnes-Integrale (Mellin "],
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", Barnes "],
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") beschrieben, die sich analytisch und numerisch (Mathai und Saxena "],
  ButtonBox["[MS1978])",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " vergleichsweise gut bearbeiten lassen. Funktionentheoretische \
Erweiterungen werden besprochen, soweit es diese Arbeit erfordert (Kapitel \
2)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "F\[UDoubleDot]r die Analytik sowie die numerische Auswertung spielt im \
Rahmen dieser Arbeit das Computeralgebrasystem "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  " eine herausragende Rolle, wobei zur Bew\[ADoubleDot]ltigung der \
gewaltigen Rechenarbeit eigens ein Computeralgebra-Paket namens "],
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  StyleBox[" erstellt wurde."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Bei der L\[ODoubleDot]sung zeit-fraktionaler Diffusionsgleichungen ist die \
L\[ODoubleDot]sung von Schneider und Wyss "],
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " zu verifizieren und besonders f\[UDoubleDot]r fraktale Raumdimensionen zu \
diskutieren. Die orts-fraktionale Diffusionsgleichung von Seshadri und West \
"],
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " ist ebenfalls zu besprechen. Au\[SZ]erdem wird eine Normalverteilung (Wei \
et al. "],
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") mit anomal zeitabh\[ADoubleDot]ngiger Varianz darauf untersucht, ob sie \
eine physikalisch leicht zug\[ADoubleDot]ngliche dynamische Gleichung als \
Grundlage besitzt. In einem konsistent kombinierten Modell einer zeit- und \
orts-fraktionalen Diffusionsgleichung ist eine varianzstabile Fassung der L\
\[ODoubleDot]sung zu finden (Kapitel 3)."]
}], "Text",
  PageBreakBelow->True],

Cell[TextData[StyleBox[
"Zwei Anwendungsbeispiele zum theoretischen Ansatz mit fraktionalen \
Diffusionsgleichungen sollen besprochen werden. Dazu stellte die Sektion \
Kernresonanzsprektroskopie der Universit\[ADoubleDot]t Ulm unter Leitung von \
Herrn Professor Dr. R. Kimmich sowie die Forschungsgruppe \
Oberfl\[ADoubleDot]chen- und Tieftemperaturphysik der Abteilung \
f\[UDoubleDot]r Physik an der Universit\[ADoubleDot]t Konstanz unter der \
Leitung von Herrn Professor Dr. P. Leiderer jeweils entsprechende \
Me\[SZ]reihen freundlicherweise zur weiteren Auswertung zur \
Verf\[UDoubleDot]gung."]], "Text"],

Cell[TextData[{
  StyleBox[
  "Der Vergleich mit Me\[SZ]daten, denen ein diffusiver Proze\[SZ] in einer \
fraktalen Raumdimension zugrundeliegt, ist vorzunehmen, wobei die \
Me\[SZ]daten (Zavada und Kimmich "],
  ButtonBox["[ZK1998]",
    ButtonData:>{"Literatur.nb", "[ZK1998]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[") Anla\[SZ] zu einer Zusammenarbeit (Zavada et al. "],
  ButtonBox["[ZSKN1999]",
    ButtonData:>{"Literatur.nb", "[ZSKN1999]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") mit der Sektion Kernresonanzspektroskopie waren. Die im Rahmen der \
Dissertation "],
  ButtonBox["[Zav1999]",
    ButtonData:>{"Literatur.nb", "[Zav1999]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " von T. Zavada (Link) noch unbeantworteten Fragen zum theoretischen Verst\
\[ADoubleDot]ndnis sind nachzuarbeiten (Kapitel 4)."]
}], "Text"],

Cell[TextData[{
  StyleBox["Ein weiterer Vergleich mit den Me\[SZ]daten (Wei et al. "],
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") zur anomalen Diffusion, die an der Universit\[ADoubleDot]t Konstanz \
aufgenommen wurden, ist mit dem errechneten Propagator der geeignetsten unter \
den fraktionalen Diffusionsgleichungen im Vergleich mit der \
varianzmodifizierten Normalverteilung vorzunehmen. Der Vergleich erfordert \
eine Fourier-Faltung, die im entsprechenden Kontext eine varianzstabile \
Alternative zu den Voigt-Profilen darstellt (Kapitel 5)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Die Arbeit wurde von Herrn Professor Dr. T. F. Nonnenmacher \
wissenschaftlich betreut. Das Programmpaket "],
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  StyleBox[
  " wurde von Herrn Professor Dr. G. Baumann mitgestaltet, der die Bedeutung \
der Computeralgebra f\[UDoubleDot]r viele Teilgebiete der Theoretischen \
Physik zu Recht hervorhebt."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Im weiteren Verlauf der Arbeit wird die im Rahmen der Computeralgebra \
\[UDoubleDot]bliche (und etwas gew\[ODoubleDot]hnungsbed\[UDoubleDot]rftige) \
Darstellung der Ergebnisse zur\[UDoubleDot]ckgenommen. Lediglich die \
Schreibweise der Funktionsnamen in der f\[UDoubleDot]r das \
Computeralgebrasystem "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" (Wolfram "],
  ButtonBox["[Wol1997]",
    ButtonData:>{"Literatur.nb", "[Wol1997]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") \[UDoubleDot]blichen Form erinnert daran, da\[SZ] alle hier \
vorgestellten Ergebnisse vom Verfasser mit der Maschine und meist auch von \
Hand durch Herrn Professor Nonnenmacher nachvollzogen worden sind."]
}], "Text"],

Cell[TextData[StyleBox[
"In den Anh\[ADoubleDot]ngen finden sich Hintergrundinformationen und \
mathematische Aspekte, die das Verst\[ADoubleDot]ndnis der Arbeit abrunden \
oder ein explizites Nachrechnen erm\[ODoubleDot]glichen."]], "Text"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1216, 687},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->13,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Einleitung"}], "Header"]}, {Cell[ 
        TextData[ {"Einleitung"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 1, 109, "Title",
  CounterAssignments->{{"Title", 3}}],
Cell[1819, 54, 57, 0, 32, "Text"],
Cell[1879, 56, 177, 4, 52, "Text"],
Cell[2059, 62, 1289, 25, 192, "Text"],
Cell[3351, 89, 1259, 34, 132, "Text"],
Cell[4613, 125, 458, 12, 72, "Text"],
Cell[5074, 139, 1139, 27, 152, "Text",
  PageBreakBelow->True],
Cell[6216, 168, 613, 9, 112, "Text"],
Cell[6832, 179, 845, 21, 112, "Text"],
Cell[7680, 202, 641, 12, 112, "Text"],
Cell[8324, 216, 406, 10, 72, "Text"],
Cell[8733, 228, 757, 17, 112, "Text"],
Cell[9493, 247, 241, 3, 52, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

